MOREBS
=======
Is a collection of methods and classes written in Python to aid in data generation, specifically
vector data. Important classes include:
- `BallComp`
- `ResplattingSearchSpaceIterator`

For the source code to this project's latest version, go to 
`https://github.com/changissz/morebs`.

# Updating

